input.radio {
	border: 1px none #000000;
	background-color: transparent;
	vertical-align: middle;
}

.panel_wrapper div.current {
	height: 80px;
}

#width {
	width: 50px;
	vertical-align: middle;
}

#width2 {
	width: 50px;
	vertical-align: middle;
}

#size {
	width: 100px;
}
