.contextMenuIEPopup {
	padding: 0;
	margin: 0;
	border: 0;
	overflow: hidden;
}

.contextMenu {
	position: absolute;
	cursor: default;
	z-index: 1000;
	border: 1px solid #D4D0C8;
	background-color: #FFFFFF;
}

.contextMenuItem, .contextMenuItemOver {
}

.contextMenuSeparator {
	width: 100%;
	background-color: #D4D0C8;
	border: 0;
}

.contextMenuImage, .contextMenuItemDisabled {
	border: 0;
}

.contextMenuIcon {
	background-color: #F0F0EE;
}

.contextMenuItemOver .contextMenuIcon {
	background-color: #B6BDD2;
}

.contextMenuIcon {
	background-color: #F0F0EE;
}

.contextMenuItemDisabled img {
	filter:progid:DXImageTransform.Microsoft.Alpha(opacity=30);
	-moz-opacity:0.3;
	opacity: 0.3;
}

.contextMenuText {
	font-family: Tahoma, Verdana, Arial, Helvetica;
	font-size: 11px;
	line-height: 20px;
}

.contextMenuItemDisabled {
	color: #AAAAAA;
}

.contextMenuText a {
	display: block;
	line-height: 20px;
	width: 100%;
	text-decoration: none;
	color: black;
	font-weight: normal;
	margin: 0;
	padding: 0;
}

.contextMenuText a:hover {
	background-color: #B6BDD2;
	text-decoration: none !important;
	font-weight: normal;
	margin: 0;
	padding: 0;
}
