html {
}

body {
    border-left: 1px solid black;
    border-right: 1px solid black;
    border-bottom: 1px solid black;
    font-size: 87%;
    font-family: "Trebuchet MS", Verdana, Helvetica, Arial, sans-serif;
    margin: auto;
    padding: 0.1em 1.0em;
    width: 40em;
}

a img {
    border: 0;
}

abbr {
    border-bottom: none;
}

#header h1 {
    font-family: "Hoefler Text", "URW Palladio L", "Palatino", "Apple Chancery", "Trebuchet MS", cursive;
    font-weight: normal;
    font-style: italic;
}

#header h1 a {
    color: black;
    text-decoration: none;
}

#main {
    width: 40em;
}

#main h2 a {
    color: black;
    text-decoration: none;
}

#main h2 a:hover {
    text-decoration: underline;
}

#main pre {
    background: #eee;
    border: 1px solid #ccc;
    border-top: 5px solid #ccc;
    border-bottom: 5px solid #ccc;
    overflow: auto;
    padding: 0.5em;
}

code {
    color: green;
}

pre code {
    color: #333;
}

.entry {
    clear: right;
    margin: 0.5em 0;
}

.menu {
    float: right;
}

p.break {
    text-align: center;
}

p.footnote {
    font-size: 0.9em;
}

#footer {
    font-size: 0.9em;
    text-align: center;
}

.login {
    margin: 0 0.5em;
}
